@@ -16,9 +16,11 @@
 #else 
 #include <qtable.h>
 #endif
+#include "miscconfig.h"
 
-class QStringList;
-
+/**
+ * Context menu commands configuration table.
+ */
 class CommandsTable : public Q3Table {
 Q_OBJECT
 
@@ -26,7 +28,6 @@ public:
 	/**
 	 * Constructor.
 	 *
-	 * @param title  title
 	 * @param parent parent widget
 	 * @param name   Qt object name
 	 */
@@ -42,19 +43,19 @@ public:
 	 *
 	 * @param cmdList command list
 	 */
-	void setCommandList(const QStringList& cmdList);
+	void setCommandList(const Q3ValueList<MiscConfig::MenuCommand>& cmdList);
 
 	/**
 	 * Get the command list from the table.
 	 *
 	 * @param cmdList the command list is returned here
 	 */
-	void getCommandList(QStringList& cmdList) const;
+	void getCommandList(Q3ValueList<MiscConfig::MenuCommand>& cmdList) const;
 
 public slots:
 	/**
 	 * Called when a value in the table is changed.
-	 * If the second cell in the last row is changed to a non-empty
+	 * If the command cell in the last row is changed to a non-empty
 	 * value, a new row is added. If it is changed to an empty value,
 	 * the row is deleted.
 	 *
@@ -76,12 +77,13 @@ public slots:
 	 * @param row row to delete
 	 */
 	void deleteRow(int row);
+
 	/**
 	 * Clear a row in the table.
 	 *
 	 * @param row row to clear
 	 */
-	void clearRow(int row_col);
+	void clearRow(int row);
 
 	/**
 	 * Display context menu.
