@@ -28,7 +28,7 @@ static const ImportSourceDialog::Properties props = {
  * @param parent  parent widget
  * @param trackDataVector track data to be filled with imported values
  */
-DiscogsDialog::DiscogsDialog(QWidget *parent,
+DiscogsDialog::DiscogsDialog(QWidget* parent,
 														 ImportTrackDataVector& trackDataVector)
 	: ImportSourceDialog(parent, "Discogs", trackDataVector,
 											 new DiscogsClient, props)
@@ -153,17 +153,19 @@ void DiscogsDialog::parseAlbumResults(const QByteArray& albumStr)
 			}
 		}
 	}
-	stHdr.genre = 255;
+	int genreNum = 255;
 	for (QStringList::const_iterator it = genreList.begin();
 			 it != genreList.end();
 			 ++it) {
-		stHdr.genre = Genres::getNumber(*it);
-		if (stHdr.genre != 255) {
+		genreNum = Genres::getNumber(*it);
+		if (genreNum != 255) {
 			break;
 		}
 	}
-	if (stHdr.genre == 255 && !genreList.empty()) {
-		stHdr.genreStr = genreList.front();
+	if (genreNum != 255) {
+		stHdr.genre = Genres::getName(genreNum);
+	} else if (!genreList.empty()) {
+		stHdr.genre = genreList.front();
 	}
 
 	/*
