@@ -40,23 +40,27 @@ public:
 	 * @param parent parent widget
 	 * @param name   Qt object name
 	 */
-	FormatBox(const QString & title, QWidget *parent = 0, const char *name = 0);
+	FormatBox(const QString& title, QWidget* parent = 0, const char* name = 0);
+
 	/**
 	 * Destructor.
 	 */
 	~FormatBox();
+
 	/**
 	 * Set the values from a format configuration.
 	 *
 	 * @param cfg format configuration
 	 */
-	void fromFormatConfig(const FormatConfig *cfg);
+	void fromFormatConfig(const FormatConfig* cfg);
+
 	/**
 	 * Store the values in a format configuration.
 	 *
 	 * @param cfg format configuration
 	 */
-	void toFormatConfig(FormatConfig *cfg) const;
+	void toFormatConfig(FormatConfig* cfg) const;
+
 public slots:
 	/**
 	 * Called when a value in the string replacement table is changed.
@@ -68,24 +72,28 @@ public slots:
 	 * @param col table column of changed item
 	 */
 	void valueChanged(int row, int col);
+
 	/**
 	 * Insert a new row into the table.
 	 *
 	 * @param row the new row is inserted after this row
 	 */
 	void insertRow(int row);
+
 	/**
 	 * Delete a row from the table.
 	 *
 	 * @param row row to delete
 	 */
 	void deleteRow(int row);
+
 	/**
 	 * Clear a cell in the table.
 	 *
 	 * @param row_col cell (row << 8 + col) to delete
 	 */
 	void clearCell(int row_col);
+
 	/**
 	 * Display context menu.
 	 *
@@ -93,11 +101,12 @@ public slots:
 	 * @param col column at which context menu is displayed
 	 * @param pos position where context menu is drawn on screen
 	 */
-	void contextMenu(int row, int col, const QPoint & pos);
+	void contextMenu(int row, int col, const QPoint& pos);
+
 private:
-	QComboBox *caseConvComboBox;
-	QCheckBox *strRepCheckBox;
-	Q3Table *strReplTable;
+	QComboBox* m_caseConvComboBox;
+	QCheckBox* m_strRepCheckBox;
+	Q3Table* m_strReplTable;
 	QCheckBox* m_formatEditingCheckBox;
 };
 
