@@ -35,6 +35,7 @@ public:
 	enum AutoStartSubDialog {
 		ASD_None,
 		ASD_Freedb,
+		ASD_TrackType,
 		ASD_Discogs,
 		ASD_MusicBrainzRelease,
 		ASD_MusicBrainz
@@ -48,7 +49,7 @@ public:
 	 * @param trackDataList track data to be filled with imported values,
 	 *                      is passed with durations of files set
 	 */
-	ImportDialog(QWidget *parent, QString &caption,
+	ImportDialog(QWidget* parent, QString& caption,
 							 ImportTrackDataVector& trackDataList);
 	/**
 	 * Destructor.
@@ -92,7 +93,7 @@ private slots:
 private:
 	AutoStartSubDialog m_autoStartSubDialog;
 	/** import selector widget */
-	ImportSelector *impsel;
+	ImportSelector* m_impsel;
 	ImportTrackDataVector& m_trackDataVector;
 };
 
