@@ -76,7 +76,23 @@ public:
 	 *
 	 * @return absolute file path.
 	 */
-	QString getAbsFilename(void) const { return m_absFilename; }
+	QString getAbsFilename() const { return m_absFilename; }
+
+	/**
+	 * Format a string from track data.
+	 * Supported format fields:
+	 * Those supported by StandardTags::formatString()
+	 * %f filename
+	 * %p path to file
+	 * %u URL of file
+	 * %d duration in minutes:seconds
+	 * %D duration in seconds
+	 *
+	 * @param format format specification
+	 *
+	 * @return formatted string.
+	 */
+	QString formatString(const QString& format) const;
 
 private:
 	int m_fileDuration;
@@ -84,10 +100,13 @@ private:
 	QString m_absFilename;
 };
 
+/**
+ * Vector containing tracks to import and artist, album names.
+ */
 class ImportTrackDataVector : public Q3ValueVector<ImportTrackData> {
 public:
-	QString artist;
-	QString album;
+	QString m_artist; /**< album artist */
+	QString m_album;  /**< album name */
 };
 
 #endif // IMPORTTRACKDATA_H
