@@ -16,6 +16,7 @@
 class KAction;
 class KRecentFilesAction;
 class KToggleAction;
+/** Base class for main window. */
 typedef KMainWindow Kid3AppBaseClass;
 #else
 #include "qtcompatmac.h"
@@ -28,6 +29,7 @@ typedef KMainWindow Kid3AppBaseClass;
 class QAction;
 class BrowserDialog;
 class Q3PopupMenu;
+/** Base class for main window. */
 typedef Q3MainWindow Kid3AppBaseClass;
 #endif
 #include "importtrackdata.h"
@@ -39,7 +41,7 @@ typedef Q3MainWindow Kid3AppBaseClass;
 #include "musicbrainzconfig.h"
 
 class KURL;
-class id3Form;
+class Id3Form;
 class TaggedFile;
 class StandardTags;
 class FrameList;
@@ -71,39 +73,32 @@ public:
 	 */
 	void openDirectory(QString dir, bool confirm = false);
 
-	/**
-	 * Update GUI controls from the tags in the files.
-	 * The new selection is stored and the GUI controls and frame list
-	 * updated accordingly (filtered for multiple selection).
-	 */
-	void updateGuiControls();
-
 	/**
 	 * Process change of selection.
 	 * The files of the current selection are updated.
 	 * The new selection is stored and the GUI controls and frame list
 	 * updated accordingly (filtered for multiple selection).
 	 */
-	void fileSelected(void);
+	void fileSelected();
 
 	/**
 	 * Update files of current selection.
 	 */
-	void updateCurrentSelection(void);
+	void updateCurrentSelection();
 
 	/**
 	 * Copy a set of standard tags into copy buffer.
 	 *
 	 * @param st tags to copy
 	 */
-	void copyTags(const StandardTags *st);
+	void copyTags(const StandardTags* st);
 
 	/**
 	 * Paste from copy buffer to standard tags.
 	 *
 	 * @param st tags to fill from data in copy buffer.
 	 */
-	void pasteTags(StandardTags *st);
+	void pasteTags(StandardTags* st);
 
 	/**
 	 * Paste from copy buffer to ID3v1 tags.
@@ -120,14 +115,14 @@ public:
 	 * If a single file is selected the tags in the GUI controls
 	 * are set, else the tags in the multiple selected files.
 	 */
-	void getTagsFromFilenameV1(void);
+	void getTagsFromFilenameV1();
 
 	/**
 	 * Set ID3v2 tags according to filename.
 	 * If a single file is selected the tags in the GUI controls
 	 * are set, else the tags in the multiple selected files.
 	 */
-	void getTagsFromFilenameV2(void);
+	void getTagsFromFilenameV2();
 
 	/**
 	 * Set filename according to tags.
@@ -141,22 +136,22 @@ public:
 	/**
 	 * Copy ID3v1 tags to ID3v2 tags of selected files.
 	 */
-	void copyV1ToV2(void);
+	void copyV1ToV2();
 
 	/**
 	 * Copy ID3v2 tags to ID3v1 tags of selected files.
 	 */
-	void copyV2ToV1(void);
+	void copyV2ToV1();
 
 	/**
 	 * Remove ID3v1 tags in selected files.
 	 */
-	void removeTagsV1(void);
+	void removeTagsV1();
 
 	/**
 	 * Remove ID3v2 tags in selected files.
 	 */
-	void removeTagsV2(void);
+	void removeTagsV2();
 
 	/**
 	 * Open directory on drop.
@@ -168,17 +163,17 @@ public:
 	/**
 	 * Edit selected frame.
 	 */
-	void editFrame(void);
+	void editFrame();
 
 	/**
 	 * Delete selected frame.
 	 */
-	void deleteFrame(void);
+	void deleteFrame();
 
 	/**
 	 * Select a frame type and add such a frame to frame list.
 	 */
-	void addFrame(void);
+	void addFrame();
 
 	/**
 	 * Display help for a topic.
@@ -197,6 +192,8 @@ public:
 	static MiscConfig s_miscCfg;
 	/** Freedb configuration */
 	static FreedbConfig s_freedbCfg;
+	/** TrackType configuration */
+	static FreedbConfig s_trackTypeCfg;
 	/** Discogs configuration */
 	static DiscogsConfig s_discogsCfg;
 	/** MusicBrainz configuration */
@@ -238,16 +235,16 @@ protected:
 	 * Saves the window properties for each open window during session end
 	 * to the session config file.
 	 *
-	 * @param _cfg application configuration
+	 * @param cfg application configuration
 	 */
-	virtual void saveProperties(KConfig *_cfg);
+	virtual void saveProperties(KConfig* cfg);
 
 	/**
 	 * Reads the session config file and restores the application's state.
 	 *
-	 * @param _cfg application configuration
+	 * @param cfg application configuration
 	 */
-	virtual void readProperties(KConfig *_cfg);
+	virtual void readProperties(KConfig* cfg);
 
 #else
 	/**
@@ -255,7 +252,7 @@ protected:
 	 *
 	 * @param ce close event
 	 */
-	void closeEvent(QCloseEvent *ce);
+	void closeEvent(QCloseEvent* ce);
 #endif
 
 	/**
@@ -271,16 +268,16 @@ protected:
 	/**
 	 * Set modification state.
 	 *
-	 * @param val TRUE if a file is modified
+	 * @param val true if a file is modified
 	 */
-	void setModified(bool val) { modified = val; }
+	void setModified(bool val) { m_modified = val; }
 
 	/**
 	 * Check modification state.
 	 *
-	 * @return TRUE if a file is modified.
+	 * @return true if a file is modified.
 	 */
-	bool isModified(void) { return modified; }
+	bool isModified() { return m_modified; }
 
 public slots:
 	/**
@@ -310,35 +307,20 @@ public slots:
 	 */
 	void slotSettingsShortcuts();
 
-	/**
-	 * Select all files.
-	 */
-	void slotSelectAll();
-
-	/**
-	 * Select next file.
-	 */
-	void slotNextFile();
-
-	/**
-	 * Select previous file.
-	 */
-	void slotPreviousFile();
-
 	/**
 	 * Display handbook.
 	 */
-	void slotHelpHandbook(void);
+	void slotHelpHandbook();
 
 	/**
 	 * Display "About" dialog.
 	 */
-	void slotHelpAbout(void);
+	void slotHelpAbout();
 
 	/**
 	 * Display "About Qt" dialog.
 	 */
-	void slotHelpAboutQt(void);
+	void slotHelpAboutQt();
 
 	/**
 	 * Revert file modifications.
@@ -361,23 +343,28 @@ public slots:
 	 *
 	 * @param text message
 	 */
-	void slotStatusMsg(const QString &text);
+	void slotStatusMsg(const QString& text);
 
 	/**
 	 * Create playlist.
 	 */
-	void slotCreatePlaylist(void);
+	void slotCreatePlaylist();
 
 	/**
 	 * Import.
 	 */
-	void slotImport(void);
+	void slotImport();
 
 	/**
 	 * Import from freedb.org.
 	 */
 	void slotImportFreedb();
 
+	/**
+	 * Import from TrackType.org.
+	 */
+	void slotImportTrackType();
+
 	/**
 	 * Import from Discogs.
 	 */
@@ -411,28 +398,45 @@ public slots:
 	/**
 	 * Preferences.
 	 */
-	void slotSettingsConfigure(void);
+	void slotSettingsConfigure();
 
 	/**
 	 * Apply filename format.
 	 */
-	void slotApplyFilenameFormat(void);
+	void slotApplyFilenameFormat();
 
 	/**
 	 * Apply ID3 format.
 	 */
-	void slotApplyId3Format(void);
+	void slotApplyId3Format();
 
 	/**
 	 * Rename directory.
 	 */
-	void slotRenameDirectory(void);
+	void slotRenameDirectory();
 
 	/**
 	 * Number tracks.
 	 */
 	void slotNumberTracks();
 
+	/**
+	 * Convert ID3v2.3 to ID3v2.4 tags.
+	 */
+	void slotConvertToId3v24();
+
+	/**
+	 * Convert ID3v2.4 to ID3v2.3 tags.
+	 */
+	void slotConvertToId3v23();
+
+	/**
+	 * Update GUI controls from the tags in the files.
+	 * The new selection is stored and the GUI controls and frame list
+	 * updated accordingly (filtered for multiple selection).
+	 */
+	void updateGuiControls();
+
 private slots:
 	/**
 	 * Set data to be exported.
@@ -448,7 +452,7 @@ private:
 	 *
 	 * @return true
 	 */
-	bool saveDirectory(void);
+	bool saveDirectory();
 
 	/**
 	 * If anything was modified, save after asking user.
@@ -462,12 +466,12 @@ private:
 	 *
 	 * @param mp3file file
 	 */
-	void updateTags(TaggedFile *mp3file);
+	void updateTags(TaggedFile* mp3file);
 
 	/**
 	 * Update modification state, caption and listbox entries.
 	 */
-	void updateModificationState(void);
+	void updateModificationState();
 
 	/**
 	 * Update ID3v2 tags in GUI controls from file displayed in frame list.
@@ -525,13 +529,13 @@ private:
 	void updateHideV2();
 
 	/** GUI with controls, created by Qt Designer */
-	id3Form *view;
-	/** TRUE if any file was modified */
-	bool modified;
+	Id3Form* m_view;
+	/** true if any file was modified */
+	bool m_modified;
 	/** Current directory */
-	QString doc_dir;
+	QString m_dirName;
 	/** Copy buffer */
-	StandardTags *copytags;
+	StandardTags* m_copyTags;
 	/** Import dialog */
 	ImportDialog* m_importDialog;
 	/** Track data list */
@@ -543,49 +547,56 @@ private:
 
 #ifdef CONFIG_USE_KDE
 	/** the configuration object of the application */
-	KConfig* config;
+	KConfig* m_config;
 	/** Actions */
-	KAction* fileOpen;
-	KRecentFilesAction* fileOpenRecent;
-	KAction* fileRevert;
-	KAction* fileSave;
-	KAction* fileQuit;
-	KToggleAction* viewToolBar;
-	KToggleAction* viewStatusBar;
+	KAction* m_fileOpen;
+	KRecentFilesAction* m_fileOpenRecent;
+	KAction* m_fileRevert;
+	KAction* m_fileSave;
+	KAction* m_fileQuit;
+	KToggleAction* m_viewToolBar;
+	KToggleAction* m_viewStatusBar;
 	KAction* settingsShortcuts;
-	KAction* settingsConfigure;
-	KAction* settingsShowHideV1;
-	KAction* settingsShowHideV2;
+	KAction* m_settingsConfigure;
+	KAction* m_settingsShowHideV1;
+	KAction* m_settingsShowHideV2;
 #else
-	Kid3Settings* config;
-	QAction* fileOpen;
-	QAction* fileSave;
-	QAction* fileRevert;
-	QAction* fileCreatePlaylist;
-	QAction* fileQuit;
-	QAction* fileImport;
-	QAction* fileImportFreedb;
-	QAction* fileImportDiscogs;
-	QAction* fileImportMusicBrainzRelease;
+	Kid3Settings* m_config;
+	QAction* m_fileOpen;
+	QAction* m_fileSave;
+	QAction* m_fileRevert;
+	QAction* m_fileCreatePlaylist;
+	QAction* m_fileQuit;
+	QAction* m_fileImport;
+	QAction* m_fileImportFreedb;
+	QAction* m_fileImportTrackType;
+	QAction* m_fileImportDiscogs;
+	QAction* m_fileImportMusicBrainzRelease;
 #ifdef HAVE_TUNEPIMP
-	QAction* fileImportMusicBrainz;
+	QAction* m_fileImportMusicBrainz;
 #endif
-	QAction* fileExport;
-	QAction* toolsApplyFilenameFormat;
-	QAction* toolsApplyId3Format;
-	QAction* toolsRenameDirectory;
-	QAction* toolsNumberTracks;
-	QAction* settingsShowHideV1;
-	QAction* settingsShowHideV2;
-	QAction* settingsConfigure;
-	QAction* helpHandbook;
-	QAction* helpAbout;
-	QAction* helpAboutQt;
-	QMenuBar* menubar;
-	Q3PopupMenu* fileMenu;
-	Q3PopupMenu* toolsMenu;
-	Q3PopupMenu* settingsMenu;
-	Q3PopupMenu* helpMenu;
+	QAction* m_fileExport;
+	QAction* m_toolsApplyFilenameFormat;
+	QAction* m_toolsApplyId3Format;
+	QAction* m_toolsRenameDirectory;
+	QAction* m_toolsNumberTracks;
+#ifdef HAVE_TAGLIB
+	QAction* m_toolsConvertToId3v24;
+#endif
+#if defined HAVE_TAGLIB && defined HAVE_ID3LIB
+	QAction* m_toolsConvertToId3v23;
+#endif
+	QAction* m_settingsShowHideV1;
+	QAction* m_settingsShowHideV2;
+	QAction* m_settingsConfigure;
+	QAction* m_helpHandbook;
+	QAction* m_helpAbout;
+	QAction* m_helpAboutQt;
+	QMenuBar* m_menubar;
+	Q3PopupMenu* m_fileMenu;
+	Q3PopupMenu* m_toolsMenu;
+	Q3PopupMenu* m_settingsMenu;
+	Q3PopupMenu* m_helpMenu;
 
 	static BrowserDialog* s_helpBrowser;
 #endif
