@@ -19,7 +19,7 @@
 #include "kid3.h"
 
 /** Description for application */
-static const char *description = I18N_NOOP("Kid3 ID3 Tagger");
+static const char* description = I18N_NOOP("Kid3 ID3 Tagger");
 
 /** Command line options */
 static KCmdLineOptions options[] =
@@ -37,12 +37,12 @@ static KCmdLineOptions options[] =
  * @return exit code of application.
  */
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
 	KAboutData aboutData(
 	    "kid3", I18N_NOOP("Kid3"),
 	    VERSION, description, KAboutData::License_GPL,
-	    "(c) 2003-2006 Urs Fleisch", 0, "http://kid3.sourceforge.net",
+	    "(c) 2003-2007 Urs Fleisch", 0, "http://kid3.sourceforge.net",
 	    "ufleisch@users.sourceforge.net");
 	aboutData.addAuthor("Urs Fleisch",0, "ufleisch@users.sourceforge.net");
 	KCmdLineArgs::init(argc, argv, &aboutData);
@@ -53,11 +53,11 @@ int main(int argc, char *argv[])
 		RESTORE(Kid3App);
 	}
 	else {
-		Kid3App *kid3 = new Kid3App();
+		Kid3App* kid3 = new Kid3App();
 		if (kid3) {
 			kid3->show();
 
-			KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+			KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
 			if (args->count()) {
 				kid3->openDirectory(QFile::decodeName(args->arg(0)));
@@ -86,21 +86,27 @@ int main(int argc, char *argv[])
  * @return exit code of application.
  */
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
 	QApplication app(argc, argv);
 
 	// translation file for Qt
 	QTranslator qt_tr(0);
+#ifdef CFG_TRANSLATIONSDIR
+	if (!qt_tr.load(QString("qt_") + QTextCodec::locale(), CFG_TRANSLATIONSDIR))
+#endif
 	qt_tr.load( QString("qt_") + QTextCodec::locale(), "." );
 	app.installTranslator(&qt_tr);
 
 	// translation file for application strings
 	QTranslator kid3_tr(0);
+#ifdef CFG_TRANSLATIONSDIR
+	if (!kid3_tr.load(QString("kid3_") + QTextCodec::locale(), CFG_TRANSLATIONSDIR))
+#endif
 	kid3_tr.load( QString("kid3_") + QTextCodec::locale(), "." );
 	app.installTranslator(&kid3_tr);
 
-	Kid3App *kid3 = new Kid3App();
+	Kid3App* kid3 = new Kid3App();
 	if (kid3) {
 		kid3->show();
 		app.setMainWidget(kid3);
