@@ -35,14 +35,78 @@ public:
 		ID3v2_4_0 = 1
 	};
 
+	/**
+	 * External command in context menu.
+	 */
+	class MenuCommand {
+	public:
+		/**
+		 * Constructor.
+		 *
+		 * @param name display name
+		 * @param cmd  command string with argument codes
+		 * @param config true if confirmation required
+		 * @param showOutput true if output of command shall be shown
+		 */
+		explicit MenuCommand(const QString& name = QString::null,
+												 const QString& cmd = QString::null,
+												 bool confirm = false, bool showOutput = false);
+
+		/**
+		 * Constructor.
+		 *
+		 * @param strList string list with encoded command
+		 */
+		explicit MenuCommand(const QStringList& strList);
+
+		/**
+		 * Encode into string list.
+		 *
+		 * @return string list with encoded command.
+		 */
+		QStringList toStringList() const;
+
+		/**
+		 * Get the display name.
+		 * @return name.
+		 */
+		const QString& getName() const { return m_name; }
+
+		/**
+		 * Get the command string.
+		 * @return command string.
+		 */
+		const QString& getCommand() const { return m_cmd; }
+
+		/**
+		 * Check if command must be confirmed.
+		 * @return true if command has to be confirmed.
+		 */
+		bool mustBeConfirmed() const { return m_confirm; }
+
+		/**
+		 * Check if command output has to be shown.
+		 * @return true if command output has to be shown.
+		 */
+		bool outputShown() const { return m_showOutput; }
+
+	private:
+		QString m_name;
+		QString m_cmd;
+		bool m_confirm;
+		bool m_showOutput;
+	};
+
 	/**
 	 * Constructor.
 	 */
-	MiscConfig(const QString &group);
+	MiscConfig(const QString& group);
+
 	/**
 	 * Destructor.
 	 */
 	virtual ~MiscConfig();
+
 	/**
 	 * Persist configuration.
 	 *
@@ -50,11 +114,12 @@ public:
 	 */
 	void writeToConfig(
 #ifdef CONFIG_USE_KDE
-		KConfig *config
+		KConfig* config
 #else
-		Kid3Settings *config
+		Kid3Settings* config
 #endif
 		) const;
+
 	/**
 	 * Read persisted configuration.
 	 *
@@ -62,12 +127,14 @@ public:
 	 */
 	void readFromConfig(
 #ifdef CONFIG_USE_KDE
-		KConfig *config
+		KConfig* config
 #else
-		Kid3Settings *config
+		Kid3Settings* config
 #endif
 		);
 
+	/** true to mark truncated ID3v1.1 fields */
+	bool m_markTruncations;
 	/** true to write total number of tracks into track fields */
 	bool m_enableTotalNumberOfTracks;
 	/** true to preserve file time stamps */
@@ -75,23 +142,23 @@ public:
 	/** field name used for Vorbis comment entries */
 	QString m_commentName;
 	/** filter of file names to be opened */
-	QString nameFilter;
+	QString m_nameFilter;
 	/** filename format */
-	QString formatText;
+	QString m_formatText;
 	/** index of filename format selected */
-	int formatItem;
+	int m_formatItem;
 	/** directory name format */
-	QString dirFormatText;
+	QString m_dirFormatText;
 	/** index of directory name format selected */
-	int dirFormatItem;
+	int m_dirFormatItem;
 	/** true to rename directory from ID3v1 tags, else ID3v2 tags */
 	bool m_renDirSrcV1;
 	/** size of splitter in main window */
-	Q3ValueList<int> splitterSizes;
+	Q3ValueList<int> m_splitterSizes;
 	/** size of file/dirlist splitter */
 	Q3ValueList<int> m_vSplitterSizes;
 	/** commands available in context menu */
-	QStringList m_contextMenuCommands;
+	Q3ValueList<MenuCommand> m_contextMenuCommands;
 	/** custom genres for ID3v2.3 */
 	QStringList m_customGenres;
 	/** true to hide ID3v1.1 controls */
@@ -104,21 +171,27 @@ public:
 	bool m_useProxy;
 	/** proxy used for access */
 	QString m_proxy;
+	/** web browser substituted for %b */
+	QString m_browser;
+	/** true to show only custom genres in combo boxes */
+	bool m_onlyCustomGenres;
 #ifndef CONFIG_USE_KDE
 	/** mainwindow width */
-	int windowWidth;
+	int m_windowWidth;
 	/** mainwindow height */
-	int windowHeight;
+	int m_windowHeight;
 #endif
 
 	/** Default name filter */
-	static const char* const defaultNameFilter;
+	static const char* const s_defaultNameFilter;
 	/** Default value for comment name */
-	static const char* const defaultCommentName;
+	static const char* const s_defaultCommentName;
+	/** Default value for web browser */
+	static const char* const s_defaultBrowser;
 	/** Default filename format list */
-	static const char** defaultFnFmtList;
+	static const char** s_defaultFnFmtList;
 	/** Default directory format list */
-	static const char** defaultDirFmtList;
+	static const char** s_defaultDirFmtList;
 };
 
 #endif
