@@ -29,10 +29,10 @@ public:
 	/**
 	 * Constructor.
 	 *
-	 * @param dn directory name
+	 * @param di directory information
 	 * @param fn filename
 	 */
-	OggFile(const QString& dn, const QString& fn);
+	OggFile(const DirInfo* di, const QString& fn);
 
 	/**
 	 * Destructor.
@@ -120,15 +120,6 @@ public:
 	 */
 	virtual int getTrackNumV2();
 
-	/**
-	 * Get ID3v2 genre.
-	 *
-	 * @return number,
-	 *         0xff if the field does not exist,
-	 *         -1 if the tags do not exist.
-	 */
-	virtual int getGenreNumV2();
-
 	/**
 	 * Get ID3v2 genre as text.
 	 *
@@ -180,13 +171,6 @@ public:
 	 */
 	virtual void setTrackNumV2(int num);
 
-	/**
-	 * Set ID3v2 genre.
-	 *
-	 * @param num number to set, 0xff to remove field.
-	 */
-	virtual void setGenreNumV2(int num);
-
 	/**
 	 * Set ID3v2 genre as text.
 	 *
