@@ -12,22 +12,22 @@
 #include <qregexp.h>
 
 #include "standardtags.h"
-#include "filelist.h"
 #include "kid3.h"
 #include "genres.h"
+#include "dirinfo.h"
 #include "taggedfile.h"
+#include <sys/stat.h>
 
 /**
  * Constructor.
  *
- * @param dn directory name
+ * @param di directory information
  * @param fn filename
  */
-TaggedFile::TaggedFile(const QString& dn, const QString& fn) :
-	dirname(dn), filename(fn), new_filename(fn)
+TaggedFile::TaggedFile(const DirInfo* di, const QString& fn) :
+	m_dirInfo(di), m_filename(fn), m_newFilename(fn),
+	m_changedV1(false), m_changedV2(false), m_truncation(0)
 {
-	changedV1 = FALSE;
-	changedV2 = FALSE;
 }
 
 /**
@@ -37,6 +37,16 @@ TaggedFile::~TaggedFile()
 {
 }
 
+/**
+ * Get directory name.
+ *
+ * @return directory name
+ */
+QString TaggedFile::getDirname() const
+{
+	return m_dirInfo->getDirname();
+}
+
 /**
  * Get ID3v1 title.
  *
@@ -112,13 +122,13 @@ int TaggedFile::getTrackNumV1()
 /**
  * Get ID3v1 genre.
  *
- * @return number,
- *         0xff if the field does not exist,
- *         -1 if the tags do not exist.
+ * @return string,
+ *         "" if the field does not exist,
+ *         QString::null if the tags do not exist.
  */
-int TaggedFile::getGenreNumV1()
+QString TaggedFile::getGenreV1()
 {
-	return -1;
+	return QString::null;
 }
 
 /**
@@ -185,11 +195,11 @@ void TaggedFile::setTrackNumV1(int)
 }
 
 /**
- * Set ID3v1 genre.
+ * Set ID3v1 genre as text.
  *
- * @param num number to set, 0xff to remove field.
+ * @param str string to set, "" to remove field, QString::null to ignore.
  */
-void TaggedFile::setGenreNumV1(int)
+void TaggedFile::setGenreV1(const QString&)
 {
 }
 
@@ -219,11 +229,10 @@ bool TaggedFile::isTagV1Supported() const
  *
  * @return absolute file path.
  */
-
-QString TaggedFile::getAbsFilename(void) const
+QString TaggedFile::getAbsFilename() const
 {
-	QDir dir(dirname);
-	return QDir::cleanDirPath(dir.absFilePath(new_filename));
+	QDir dir(m_dirInfo->getDirname());
+	return QDir::cleanDirPath(dir.absFilePath(m_newFilename));
 }
 
 /**
@@ -231,8 +240,7 @@ QString TaggedFile::getAbsFilename(void) const
  *
  * @param st tags to put result
  */
-
-void TaggedFile::getStandardTagsV1(StandardTags *st)
+void TaggedFile::getStandardTagsV1(StandardTags* st)
 {
 	st->title = getTitleV1();
 	st->artist = getArtistV1();
@@ -240,8 +248,7 @@ void TaggedFile::getStandardTagsV1(StandardTags *st)
 	st->comment = getCommentV1();
 	st->year = getYearV1();
 	st->track = getTrackNumV1();
-	st->genre = getGenreNumV1();
-	st->genreStr = QString::null;
+	st->genre = getGenreV1();
 }
 
 /**
@@ -249,8 +256,7 @@ void TaggedFile::getStandardTagsV1(StandardTags *st)
  *
  * @param st tags to put result
  */
-
-void TaggedFile::getStandardTagsV2(StandardTags *st)
+void TaggedFile::getStandardTagsV2(StandardTags* st)
 {
 	st->title = getTitleV2();
 	st->artist = getArtistV2();
@@ -258,8 +264,7 @@ void TaggedFile::getStandardTagsV2(StandardTags *st)
 	st->comment = getCommentV2();
 	st->year = getYearV2();
 	st->track = getTrackNumV2();
-	st->genre = getGenreNumV2();
-	st->genreStr = st->genre == 0xff ? getGenreV2() : QString::null;
+	st->genre = getGenreV2();
 }
 
 /**
@@ -268,8 +273,7 @@ void TaggedFile::getStandardTagsV2(StandardTags *st)
  * @param st tags to set
  * @param flt filter specifying which fields to set
  */
-
-void TaggedFile::setStandardTagsV1(const StandardTags *st,
+void TaggedFile::setStandardTagsV1(const StandardTags* st,
 																	 const StandardTagsFilter& flt)
 {
 	StandardTags oldst;
@@ -293,7 +297,7 @@ void TaggedFile::setStandardTagsV1(const StandardTags *st,
 		setTrackNumV1(st->track);
 	}
 	if (flt.m_enableGenre && st->genre != oldst.genre) {
-		setGenreNumV1(st->genre);
+		setGenreV1(st->genre);
 	}
 }
 
@@ -303,8 +307,7 @@ void TaggedFile::setStandardTagsV1(const StandardTags *st,
  * @param st tags to set
  * @param flt filter specifying which fields to set
  */
-
-void TaggedFile::setStandardTagsV2(const StandardTags *st,
+void TaggedFile::setStandardTagsV2(const StandardTags* st,
 																	 const StandardTagsFilter& flt)
 {
 	StandardTags oldst;
@@ -327,13 +330,8 @@ void TaggedFile::setStandardTagsV2(const StandardTags *st,
 	if (flt.m_enableTrack && st->track != oldst.track) {
 		setTrackNumV2(st->track);
 	}
-	if (flt.m_enableGenre &&
-			(st->genre != oldst.genre || st->genreStr != oldst.genreStr)) {
-		if (st->genre != 0xff) {
-			setGenreNumV2(st->genre);
-		} else {
-			setGenreV2(st->genreStr);
-		}
+	if (flt.m_enableGenre && st->genre != oldst.genre) {
+		setGenreV2(st->genre);
 	}
 }
 
@@ -344,7 +342,6 @@ void TaggedFile::setStandardTagsV2(const StandardTags *st,
  *
  * @param album album string
  */
-
 static void remove_artist(QString& album)
 {
 	int pos = album.find(" - ");
@@ -376,7 +373,7 @@ static void remove_artist(QString& album)
  *            %y year
  *            %t track
  */
-void TaggedFile::getTagsFromFilename(StandardTags *st, QString fmt)
+void TaggedFile::getTagsFromFilename(StandardTags* st, QString fmt)
 {
 	QRegExp re;
 	QString fn(getAbsFilename());
@@ -531,7 +528,7 @@ void TaggedFile::getTagsFromFilename(StandardTags *st, QString fmt)
  *
  * @return format string with format codes replaced by tags.
  */
-QString TaggedFile::formatWithTags(const StandardTags *st, QString fmt,
+QString TaggedFile::formatWithTags(const StandardTags* st, QString fmt,
 								   bool isDirname) const
 {
 	if (!isDirname) {
@@ -544,52 +541,7 @@ QString TaggedFile::formatWithTags(const StandardTags *st, QString fmt,
 		fmt += getFileExtension();
 	}
 
-	const int num_tag_codes = 7;
-	const QChar tag_code[num_tag_codes] = {
-	    's', 'l', 'a', 'c', 'y', 't', 'g'};
-	QString tag_str[num_tag_codes];
-	QString insert_str[num_tag_codes];
-	QString year, track;
-	year.sprintf("%d", st->year);
-	track.sprintf("%02d", st->track);
-	tag_str[0] = st->title;
-	tag_str[1] = st->album;
-	tag_str[2] = st->artist;
-	tag_str[3] = st->comment;
-	tag_str[4] = year;
-	tag_str[5] = track;
-	tag_str[6] = Genres::getName(st->genre);
-	int pos = 0, i;
-	for (i = 0;; ++i) {
-		pos = fmt.find('%', pos);
-		if (pos == -1) break;
-		if (i >= num_tag_codes) {
-			// maximum of insert strings reached,
-			// remove rest of string
-			fmt.truncate(pos);
-			break;
-		}
-		++pos;
-		insert_str[i] = "";
-		for (int k = 0;; ++k) {
-			if (k >= num_tag_codes) {
-				// invalid code at pos, remove it
-				fmt.remove(--pos, 2);
-				break;
-			}
-			if (fmt[pos] == tag_code[k]) {
-				// code found, prepare format and string for sprintf
-				fmt[pos] = i + '0';
-				insert_str[i] = tag_str[k];
-				++pos;
-				break;
-			}
-		}
-	}
-	for (int k = 0; k < i; ++k) {
-		fmt = fmt.arg(insert_str[k]);
-	}
-	return fmt;
+	return st->formatString(fmt);
 }
 
 /**
@@ -605,9 +557,9 @@ QString TaggedFile::formatWithTags(const StandardTags *st, QString fmt,
  *            %t track
  *            %g genre
  */
-void TaggedFile::getFilenameFromTags(const StandardTags *st, QString fmt)
+void TaggedFile::getFilenameFromTags(const StandardTags* st, QString fmt)
 {
-	new_filename = formatWithTags(st, fmt);
+	m_newFilename = formatWithTags(st, fmt);
 }
 
 /**
@@ -645,7 +597,25 @@ QString TaggedFile::formatTime(unsigned seconds)
  */
 bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
 {
+	QString dirname = m_dirInfo->getDirname();
 	if (fnNew.lower() == fnOld.lower()) {
+		// If the filenames only differ in case, the new file is reported to
+		// already exist on case insensitive filesystems (e.g. Windows),
+		// so it is checked if the new file is really the old file by
+		// comparing inodes and devices. If the files are not the same,
+		// another file would be overwritten and an error is reported.
+		if (QFile::exists(dirname + QDir::separator() + fnNew)) {
+			struct stat statOld, statNew;
+			if (::stat((dirname + QDir::separator() + fnOld).latin1(), &statOld) == 0 &&
+					::stat((dirname + QDir::separator() + fnNew).latin1(), &statNew) == 0 &&
+					!(statOld.st_ino == statNew.st_ino &&
+						statOld.st_dev == statNew.st_dev)) {
+				qDebug("rename(%s, %s): %s already exists", fnOld.latin1(),
+							 fnNew.latin1(), fnNew.latin1());
+				return false;
+			}
+		}
+
 		// if the filenames only differ in case, first rename to a
 		// temporary filename, so that it works also with case
 		// insensitive filesystems (e.g. Windows).
@@ -661,12 +631,14 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
 					   fnNew.latin1());
 			return false;
 		}
-	} else if (!QFile::exists(dirname + QDir::separator() + fnNew)) {
-		if (!QDir(dirname).rename(fnOld, fnNew)) {
-			qDebug("rename(%s, %s) failed", fnOld.latin1(),
-					   fnNew.latin1());
-			return false;
-		}
+	} else if (QFile::exists(dirname + QDir::separator() + fnNew)) {
+		qDebug("rename(%s, %s): %s already exists", fnOld.latin1(),
+					 fnNew.latin1(), fnNew.latin1());
+		return false;
+	} else if (!QDir(dirname).rename(fnOld, fnNew)) {
+		qDebug("rename(%s, %s) failed", fnOld.latin1(),
+					 fnNew.latin1());
+		return false;
 	}
 	return true;
 }
@@ -691,7 +663,7 @@ int TaggedFile::getTotalNumberOfTracksIfEnabled() const
 {
 	int numTracks = -1;
 	if (Kid3App::s_miscCfg.m_enableTotalNumberOfTracks) {
-		numTracks = FileList::getNumberOfFiles();
+		numTracks = m_dirInfo->getNumFiles();
 	}
 	return numTracks;
 }
@@ -709,7 +681,7 @@ void TaggedFile::removeStandardTagsV1(const StandardTagsFilter& flt)
 	if (flt.m_enableComment) setCommentV1("");
 	if (flt.m_enableYear)    setYearV1(0);
 	if (flt.m_enableTrack)   setTrackNumV1(0);
-	if (flt.m_enableGenre)   setGenreNumV1(0xff);
+	if (flt.m_enableGenre)   setGenreV1("");
 }
 
 /**
@@ -725,7 +697,7 @@ void TaggedFile::removeStandardTagsV2(const StandardTagsFilter& flt)
 	if (flt.m_enableComment) setCommentV2("");
 	if (flt.m_enableYear)    setYearV2(0);
 	if (flt.m_enableTrack)   setTrackNumV2(0);
-	if (flt.m_enableGenre)   setGenreNumV2(0xff);
+	if (flt.m_enableGenre)   setGenreV2("");
 }
 
 /**
@@ -751,3 +723,47 @@ QString TaggedFile::getTagFormatV2() const
 {
 	return QString::null;
 }
+
+/**
+ * Check if a string has to be truncated.
+ *
+ * @param str  string to be checked
+ * @param flag flag to be set if string has to be truncated
+ * @param len  maximum length of string
+ *
+ * @return str truncated to len characters if necessary, else QString::null.
+ */
+QString TaggedFile::checkTruncation(
+	const QString& str, StandardTags::TruncationFlag flag, int len)
+{
+	if (static_cast<int>(str.length()) > len) {
+		QString s = str;
+		s.truncate(len);
+		m_truncation |= flag;
+		return s;
+	} else {
+		m_truncation &= ~flag;
+		return QString::null;
+	}
+}
+
+/**
+ * Check if a number has to be truncated.
+ *
+ * @param val  value to be checked
+ * @param flag flag to be set if number has to be truncated
+ * @param max  maximum value
+ *
+ * @return val truncated to max if necessary, else -1.
+ */
+int TaggedFile::checkTruncation(int val, StandardTags::TruncationFlag flag,
+																int max)
+{
+	if (val > max) {
+		m_truncation |= flag;
+		return max;
+	} else {
+		m_truncation &= ~flag;
+		return -1;
+	}
+}
