@@ -11,10 +11,10 @@
 #define TAGGEDFILE_H
 
 #include <qstring.h>
+#include "standardtags.h"
 
-class StandardTags;
-class StandardTagsFilter;
 class FrameList;
+class DirInfo;
 
 /** Base class for tagged files. */
 class TaggedFile {
@@ -22,10 +22,10 @@ public:
 	/**
 	 * Constructor.
 	 *
-	 * @param dn directory name
+	 * @param di directory information
 	 * @param fn filename
 	 */
-	TaggedFile(const QString& dn, const QString& fn);
+	TaggedFile(const DirInfo* di, const QString& fn);
 
 	/**
 	 * Destructor.
@@ -37,41 +37,48 @@ public:
 	 *
 	 * @param fn file name
 	 */
-	void setFilename(const QString& fn) { new_filename = fn; }
+	void setFilename(const QString& fn) { m_newFilename = fn; }
 
 	/**
 	 * Get file name.
 	 *
 	 * @return file name
 	 */
-	QString getFilename(void) const { return new_filename; }
+	const QString& getFilename() const { return m_newFilename; }
 
 	/**
 	 * Get directory name.
 	 *
 	 * @return directory name
 	 */
-	QString getDirname(void) const { return dirname; }
+	QString getDirname() const;
+
+	/**
+	 * Get information about directory.
+	 *
+	 * @return directory information.
+	 */
+	const DirInfo* getDirInfo() const { return m_dirInfo; }
 
 	/**
 	 * Read tags from file.
 	 *
-	 * @param force TRUE to force reading even if tags were already read.
+	 * @param force true to force reading even if tags were already read.
 	 */
 	virtual void readTags(bool force) = 0;
 
 	/**
 	 * Write tags to file and rename it if necessary.
 	 *
-	 * @param force   TRUE to force writing even if file was not changed.
-	 * @param renamed will be set to TRUE if the file was renamed,
+	 * @param force   true to force writing even if file was not changed.
+	 * @param renamed will be set to true if the file was renamed,
 	 *                i.e. the file name is no longer valid, else *renamed
 	 *                is left unchanged
 	 * @param preserve true to preserve file time stamps
 	 *
-	 * @return TRUE if ok, FALSE if the file could not be written or renamed.
+	 * @return true if ok, false if the file could not be written or renamed.
 	 */
-	virtual bool writeTags(bool force, bool *renamed, bool preserve) = 0;
+	virtual bool writeTags(bool force, bool* renamed, bool preserve) = 0;
 
 	/**
 	 * Get ID3v1 title.
@@ -130,11 +137,11 @@ public:
 	/**
 	 * Get ID3v1 genre.
 	 *
-	 * @return number,
-	 *         0xff if the field does not exist,
-	 *         -1 if the tags do not exist.
+	 * @return string,
+	 *         "" if the field does not exist,
+	 *         QString::null if the tags do not exist.
 	 */
-	virtual int getGenreNumV1();
+	virtual QString getGenreV1();
 
 	/**
 	 * Remove all ID3v1 tags.
@@ -186,11 +193,11 @@ public:
 	virtual void setTrackNumV1(int num);
 
 	/**
-	 * Set ID3v1 genre.
+	 * Set ID3v1 genre as text.
 	 *
-	 * @param num number to set, 0xff to remove field.
+	 * @param str string to set, "" to remove field, QString::null to ignore.
 	 */
-	virtual void setGenreNumV1(int num);
+	virtual void setGenreV1(const QString& str);
 
 	/**
 	 * Check if file has an ID3v1 tag.
@@ -214,7 +221,7 @@ public:
 	 *         "" if the field does not exist,
 	 *         QString::null if the tags do not exist.
 	 */
-	virtual QString getTitleV2(void) = 0;
+	virtual QString getTitleV2() = 0;
 
 	/**
 	 * Get ID3v2 artist.
@@ -223,7 +230,7 @@ public:
 	 *         "" if the field does not exist,
 	 *         QString::null if the tags do not exist.
 	 */
-	virtual QString getArtistV2(void) = 0;
+	virtual QString getArtistV2() = 0;
 
 	/**
 	 * Get ID3v2 album.
@@ -232,7 +239,7 @@ public:
 	 *         "" if the field does not exist,
 	 *         QString::null if the tags do not exist.
 	 */
-	virtual QString getAlbumV2(void) = 0;
+	virtual QString getAlbumV2() = 0;
 
 	/**
 	 * Get ID3v2 comment.
@@ -241,7 +248,7 @@ public:
 	 *         "" if the field does not exist,
 	 *         QString::null if the tags do not exist.
 	 */
-	virtual QString getCommentV2(void) = 0;
+	virtual QString getCommentV2() = 0;
 
 	/**
 	 * Get ID3v2 year.
@@ -250,7 +257,7 @@ public:
 	 *         0 if the field does not exist,
 	 *         -1 if the tags do not exist.
 	 */
-	virtual int getYearV2(void) = 0;
+	virtual int getYearV2() = 0;
 
 	/**
 	 * Get ID3v2 track.
@@ -259,16 +266,7 @@ public:
 	 *         0 if the field does not exist,
 	 *         -1 if the tags do not exist.
 	 */
-	virtual int getTrackNumV2(void) = 0;
-
-	/**
-	 * Get ID3v2 genre.
-	 *
-	 * @return number,
-	 *         0xff if the field does not exist,
-	 *         -1 if the tags do not exist.
-	 */
-	virtual int getGenreNumV2(void) = 0;
+	virtual int getTrackNumV2() = 0;
 
 	/**
 	 * Remove all ID3v2 tags.
@@ -328,13 +326,6 @@ public:
 	 */
 	virtual void setTrackNumV2(int num) = 0;
 
-	/**
-	 * Set ID3v2 genre.
-	 *
-	 * @param num number to set, 0xff to remove field.
-	 */
-	virtual void setGenreNumV2(int num) = 0;
-
 	/**
 	 * Set ID3v2 genre as text.
 	 *
@@ -412,14 +403,14 @@ public:
 	 *
 	 * @param st tags to put result
 	 */
-	void getStandardTagsV1(StandardTags *st);
+	void getStandardTagsV1(StandardTags* st);
 
 	/**
 	 * Get ID3v2 tags from file.
 	 *
 	 * @param st tags to put result
 	 */
-	void getStandardTagsV2(StandardTags *st);
+	void getStandardTagsV2(StandardTags* st);
 
 	/**
 	 * Set ID3v1 tags.
@@ -427,7 +418,7 @@ public:
 	 * @param st tags to set
 	 * @param flt filter specifying which fields to set
 	 */
-	void setStandardTagsV1(const StandardTags *st,
+	void setStandardTagsV1(const StandardTags* st,
 												 const StandardTagsFilter& flt);
 	/**
 	 * Set ID3v2 tags.
@@ -435,7 +426,7 @@ public:
 	 * @param st tags to set
 	 * @param flt filter specifying which fields to set
 	 */
-	void setStandardTagsV2(const StandardTags *st,
+	void setStandardTagsV2(const StandardTags* st,
 												 const StandardTagsFilter& flt);
 	/**
 	 * Get tags from filename.
@@ -451,7 +442,7 @@ public:
 	 *            %y year
 	 *            %t track
 	 */
-	void getTagsFromFilename(StandardTags *st, QString fmt);
+	void getTagsFromFilename(StandardTags* st, QString fmt);
 
 	/**
 	 * Create string with tags according to format string.
@@ -469,7 +460,7 @@ public:
 	 *
 	 * @return format string with format codes replaced by tags.
 	 */
-	QString formatWithTags(const StandardTags *st, QString fmt,
+	QString formatWithTags(const StandardTags* st, QString fmt,
 	                       bool isDirname = false) const;
 
 	/**
@@ -485,22 +476,40 @@ public:
 	 *            %t track
 	 *            %g genre
 	 */
-	void getFilenameFromTags(const StandardTags *st, QString fmt);
+	void getFilenameFromTags(const StandardTags* st, QString fmt);
 
 	/**
 	 * Check if file is changed.
 	 *
-	 * @return TRUE if file was changed.
+	 * @return true if file was changed.
 	 */
-	bool isChanged(void) const { return changedV1 || changedV2 ||
-																 new_filename != filename; }
+	bool isChanged() const { return m_changedV1 || m_changedV2 ||
+			m_newFilename != m_filename; }
 
 	/**
 	 * Get absolute filename.
 	 *
 	 * @return absolute file path.
 	 */
-	QString getAbsFilename(void) const;
+	QString getAbsFilename() const;
+
+	/**
+	 * Check if tag 2 was changed.
+	 * @return true if tag 2 was changed.
+	 */
+	bool isTag2Changed() const { return m_changedV2; }
+
+	/**
+	 * Mark tag 2 as changed.
+	 * @param changed true if tag is changed
+	 */
+	void markTag2Changed(bool changed = true) { m_changedV2 = changed; }
+
+	/**
+	 * Get the truncation flags.
+	 * @return truncation flags.
+	 */
+	unsigned getTruncationFlags() const { return m_truncation; }
 
 	/**
 	 * Format a time string "h:mm:ss".
@@ -513,9 +522,6 @@ public:
 	 */
 	static QString formatTime(unsigned seconds);
 
-	/** TRUE if ID3v2 tags were changed */
-	bool changedV2;
-
 protected:
 	/**
 	 * Rename a file.
@@ -557,18 +563,77 @@ protected:
 	 */
 	void removeStandardTagsV2(const StandardTagsFilter& flt);
 
-	/** Directory name */
-	const QString dirname;
-	/** File name */
-	const QString filename;
-	/** New file name */
-	QString new_filename;
-	/** TRUE if ID3v1 tags were changed */
-	bool changedV1;
+	/**
+	 * Get current filename.
+	 * @return existing name.
+	 */
+	const QString& currentFilename() const { return m_filename; }
+
+	/**
+	 * Set current filename to new filename.
+	 */
+	void updateCurrentFilename() { m_filename = m_newFilename; }
+
+	/**
+	 * Check if tag 1 was changed.
+	 * @return true if tag 1 was changed.
+	 */
+	bool isTag1Changed() const { return m_changedV1; }
+
+	/**
+	 * Mark tag 1 as changed.
+	 * @param changed true if tag is changed
+	 */
+	void markTag1Changed(bool changed = true) {
+		m_changedV1 = changed;
+		if (!m_changedV1) clearTrunctionFlags();
+	}
+
+	/**
+	 * Check if a string has to be truncated.
+	 *
+	 * @param str  string to be checked
+	 * @param flag flag to be set if string has to be truncated
+	 * @param len  maximum length of string
+	 *
+	 * @return str truncated to len characters if necessary, else QString::null.
+	 */
+	QString checkTruncation(const QString& str,
+													StandardTags::TruncationFlag flag, int len = 30);
+
+	/**
+	 * Check if a number has to be truncated.
+	 *
+	 * @param val  value to be checked
+	 * @param flag flag to be set if number has to be truncated
+	 * @param max  maximum value
+	 *
+	 * @return val truncated to max if necessary, else -1.
+	 */
+	int checkTruncation(int val, StandardTags::TruncationFlag flag,
+											int max = 255);
+
+	/**
+	 * Clear all truncation flags.
+	 */
+	void clearTrunctionFlags() { m_truncation = 0; }
 
 private:
 	TaggedFile(const TaggedFile&);
 	TaggedFile& operator=(const TaggedFile&);
+
+	/** Directory information */
+	const DirInfo* m_dirInfo;
+	/** File name */
+	QString m_filename;
+	/** New file name */
+	QString m_newFilename;
+	/** true if ID3v1 tags were changed */
+	bool m_changedV1;
+	/** true if ID3v2 tags were changed */
+	bool m_changedV2;
+	/** Truncation flags. */
+	unsigned m_truncation;
 };
 
 #endif // TAGGEDFILE_H
