@@ -20,6 +20,7 @@
 #include "standardtags.h"
 #include "taglibframelist.h"
 #include "genres.h"
+#include "dirinfo.h"
 #include <sys/stat.h>
 #ifdef WIN32
 #include <sys/utime.h>
@@ -45,11 +46,11 @@
 /**
  * Constructor.
  *
- * @param dn directory name
+ * @param di directory information
  * @param fn filename
  */
-TagLibFile::TagLibFile(const QString& dn, const QString& fn) :
-	TaggedFile(dn, fn), m_tagV1(0), m_tagV2(0), m_fileRead(false)
+TagLibFile::TagLibFile(const DirInfo* di, const QString& fn) :
+	TaggedFile(di, fn), m_tagV1(0), m_tagV2(0), m_fileRead(false)
 {
 }
 
@@ -67,14 +68,14 @@ TagLibFile::~TagLibFile()
  */
 void TagLibFile::readTags(bool force)
 {
-	Q3CString fn = QFile::encodeName(dirname + QDir::separator() + filename);
+	Q3CString fn = QFile::encodeName(getDirInfo()->getDirname() + QDir::separator() + currentFilename());
 
 	if (force || m_fileRef.isNull()) {
 		m_fileRef = TagLib::FileRef(fn);
 		m_tagV1 = 0;
 		m_tagV2 = 0;
-		changedV1 = false;
-		changedV2 = false;
+		markTag1Changed(false);
+		markTag2Changed(false);
 		m_fileRead = true;
 	}
 
@@ -88,44 +89,44 @@ void TagLibFile::readTags(bool force)
 		if ((mpegFile = dynamic_cast<TagLib::MPEG::File*>(file)) != 0) {
 			if (!m_tagV1) {
 				m_tagV1 = mpegFile->ID3v1Tag();
-				changedV1 = false;
+				markTag1Changed(false);
 			}
 			if (!m_tagV2) {
 				m_tagV2 = mpegFile->ID3v2Tag();
-				changedV2 = false;
+				markTag2Changed(false);
 			}
 		} else if ((flacFile = dynamic_cast<TagLib::FLAC::File*>(file)) != 0) {
 			if (!m_tagV1) {
 				m_tagV1 = flacFile->ID3v1Tag();
-				changedV1 = false;
+				markTag1Changed(false);
 			}
 			if (!m_tagV2) {
 				m_tagV2 = flacFile->xiphComment();
-				changedV2 = false;
+				markTag2Changed(false);
 			}
 #ifdef MPC_ID3V1
 		} else if ((mpcFile = dynamic_cast<TagLib::MPC::File*>(file)) != 0) {
 			if (!m_tagV1) {
 				m_tagV1 = mpcFile->ID3v1Tag();
-				changedV1 = false;
+				markTag1Changed(false);
 			}
 			if (!m_tagV2) {
 				m_tagV2 = mpcFile->APETag();
-				changedV2 = false;
+				markTag2Changed(false);
 			}
 #endif
 		} else {
 			m_tagV1 = 0;
-			changedV1 = false;
+			markTag1Changed(false);
 			if (!m_tagV2) {
 				m_tagV2 = m_fileRef.tag();
-				changedV2 = false;
+				markTag2Changed(false);
 			}
 		}
 	}
 
 	if (force) {
-		new_filename = filename;
+		setFilename(currentFilename());
 	}
 }
 
@@ -140,9 +141,9 @@ void TagLibFile::readTags(bool force)
  *
  * @return true if ok, false if the file could not be written or renamed.
  */
-bool TagLibFile::writeTags(bool force, bool *renamed, bool preserve)
+bool TagLibFile::writeTags(bool force, bool* renamed, bool preserve)
 {
-	QString fnStr(dirname + QDir::separator() + filename);
+	QString fnStr(getDirInfo()->getDirname() + QDir::separator() + currentFilename());
 	if (isChanged() && !QFileInfo(fnStr).isWritable()) {
 		return false;
 	}
@@ -166,39 +167,39 @@ bool TagLibFile::writeTags(bool force, bool *renamed, bool preserve)
 	if (!m_fileRef.isNull() && (file = m_fileRef.file()) != 0) {
 		TagLib::MPEG::File* mpegFile = dynamic_cast<TagLib::MPEG::File*>(file);
 		if (mpegFile) {
-			if (m_tagV1 && (force || changedV1) && m_tagV1->isEmpty()) {
+			if (m_tagV1 && (force || isTag1Changed()) && m_tagV1->isEmpty()) {
 				mpegFile->strip(TagLib::MPEG::File::ID3v1);
 				fileChanged = true;
-				changedV1 = false;
+				markTag1Changed(false);
 				m_tagV1 = 0;
 			}
-			if (m_tagV2 && (force || changedV2) && m_tagV2->isEmpty()) {
+			if (m_tagV2 && (force || isTag2Changed()) && m_tagV2->isEmpty()) {
 				mpegFile->strip(TagLib::MPEG::File::ID3v2);
 				fileChanged = true;
-				changedV2 = false;
+				markTag2Changed(false);
 				m_tagV2 = 0;
 			}
 			int saveMask = 0;
-			if (m_tagV1 && (force || changedV1) && !m_tagV1->isEmpty()) {
+			if (m_tagV1 && (force || isTag1Changed()) && !m_tagV1->isEmpty()) {
 				saveMask |= TagLib::MPEG::File::ID3v1;
 			}
-			if (m_tagV2 && (force || changedV2) && !m_tagV2->isEmpty()) {
+			if (m_tagV2 && (force || isTag2Changed()) && !m_tagV2->isEmpty()) {
 				saveMask |= TagLib::MPEG::File::ID3v2;
 			}
 			if (saveMask != 0) {
 				if (mpegFile->save(saveMask, false)) {
 					fileChanged = true;
 					if (saveMask & TagLib::MPEG::File::ID3v1) {
-						changedV1 = false;
+						markTag1Changed(false);
 					}
 					if (saveMask & TagLib::MPEG::File::ID3v2) {
-						changedV2 = false;
+						markTag2Changed(false);
 					}
 				}
 			}
 		} else {
-			if ((m_tagV2 && (force || changedV2)) ||
-					(m_tagV1 && (force || changedV1))) {
+			if ((m_tagV2 && (force || isTag2Changed())) ||
+					(m_tagV1 && (force || isTag1Changed()))) {
 				TagLib::MPC::File* mpcFile = dynamic_cast<TagLib::MPC::File*>(file);
 #ifndef MPC_ID3V1
 				// it does not work if there is also an ID3 tag (bug in TagLib?)
@@ -209,8 +210,8 @@ bool TagLibFile::writeTags(bool force, bool *renamed, bool preserve)
 #endif
 				if (m_fileRef.save()) {
 					fileChanged = true;
-					changedV1 = false;
-					changedV2 = false;
+					markTag1Changed(false);
+					markTag2Changed(false);
 				}
 			}
 		}
@@ -222,28 +223,33 @@ bool TagLibFile::writeTags(bool force, bool *renamed, bool preserve)
 	// file reference is assigned, later readTags() is called.
 	// If the file is not properly closed, doubled tags can be
 	// written if the file is finally closed!
-	// This can be reproduced with an untag MP3 file, then add
+	// This can be reproduced with an untagged MP3 file, then add
 	// an ID3v2 title, save, add an ID3v2 artist, save, reload
-	// => double ID3v2 tags. 
-	if (fileChanged) {
+	// => double ID3v2 tags.
+	// On Windows it is necessary to close the file before renaming it,
+	// so it is done even if the file is not changed.
+#ifndef WIN32
+	if (fileChanged)
+#endif
 		m_fileRef = TagLib::FileRef();
-	}
 
 	// restore time stamp
 	if (setUtime) {
 		::utime(fn, &times);
 	}
 
-	if (new_filename != filename) {
-		if (!renameFile(filename, new_filename)) {
+	if (getFilename() != currentFilename()) {
+		if (!renameFile(currentFilename(), getFilename())) {
 			return false;
 		}
+		updateCurrentFilename();
 		*renamed = true;
 	}
 
-	if (fileChanged) {
+#ifndef WIN32
+	if (fileChanged)
+#endif
 		readTags(true);
-	}
 	return true;
 }
 
@@ -277,7 +283,7 @@ void TagLibFile::removeTagsV2(const StandardTagsFilter& flt)
 						 it != frameList.end();) {
 					id3v2Tag->removeFrame(*it++, true);
 				}
-				changedV2 = true;
+				markTag2Changed();
 			} else if ((oggTag = dynamic_cast<TagLib::Ogg::XiphComment*>(m_tagV2)) !=
 								 0) {
 				const TagLib::Ogg::FieldListMap& fieldListMap = oggTag->fieldListMap();
@@ -285,14 +291,14 @@ void TagLibFile::removeTagsV2(const StandardTagsFilter& flt)
 						 it != fieldListMap.end();) {
 					oggTag->removeField((*it++).first);
 				}
-				changedV2 = true;
+				markTag2Changed();
 			} else if ((apeTag = dynamic_cast<TagLib::APE::Tag*>(m_tagV2)) != 0) {
 				const TagLib::APE::ItemListMap& itemListMap = apeTag->itemListMap();
 				for (TagLib::APE::ItemListMap::ConstIterator it = itemListMap.begin();
 						 it != itemListMap.end();) {
 					apeTag->removeItem((*it++).first);
 				}
-				changedV2 = true;
+				markTag2Changed();
 			} else {
 				removeStandardTagsV2(flt);
 			}
@@ -405,21 +411,17 @@ int TagLibFile::getTrackNumV1()
 /**
  * Get ID3v1 genre.
  *
- * @return number,
- *         0xff if the field does not exist,
- *         -1 if the tags do not exist.
+ * @return string,
+ *         "" if the field does not exist,
+ *         QString::null if the tags do not exist.
  */
-int TagLibFile::getGenreNumV1()
+QString TagLibFile::getGenreV1()
 {
 	if (m_tagV1) {
 		TagLib::String str = m_tagV1->genre();
-		if (!str.isNull()) {
-			return Genres::getNumber(TStringToQString(str));
-		} else {
-			return 0xff;
-		}
+		return str.isNull() ? QString("") : TStringToQString(str);
 	} else {
-		return -1;
+		return QString::null;
 	}
 }
 
@@ -524,36 +526,32 @@ int TagLibFile::getTrackNumV2()
 }
 
 /**
- * Get ID3v2 genre.
+ * Get a genre string from a string which can contain the genre itself,
+ * or only the genre number or the genre number in parenthesis.
  *
- * @return number,
- *         0xff if the field does not exist,
- *         -1 if the tags do not exist.
+ * @param str genre string
+ *
+ * @return genre.
  */
-int TagLibFile::getGenreNumV2()
+static QString getGenreString(const TagLib::String& str)
 {
-	if (m_tagV2) {
-		TagLib::String str = m_tagV2->genre();
-		if (!str.isNull()) {
-			QString qs = TStringToQString(str);
-			int cpPos = 0, n = 0xff;
-			bool ok = false;
-			if (qs[0] == '(' && (cpPos = qs.find(')', 2)) > 1) {
-				n = qs.mid(1, cpPos - 1).toInt(&ok);
-				if (!ok || n > 0xff) {
-					n = 0xff;
-				}
-				return n;
-			} else if ((n = qs.toInt(&ok)) >= 0 && n <= 0xff && ok) {
-				return n;
-			} else {
-				return Genres::getNumber(qs);
+	if (!str.isNull()) {
+		QString qs = TStringToQString(str);
+		int cpPos = 0, n = 0xff;
+		bool ok = false;
+		if (qs[0] == '(' && (cpPos = qs.find(')', 2)) > 1) {
+			n = qs.mid(1, cpPos - 1).toInt(&ok);
+			if (!ok || n > 0xff) {
+				n = 0xff;
 			}
+			return Genres::getName(n);
+		} else if ((n = qs.toInt(&ok)) >= 0 && n <= 0xff && ok) {
+			return Genres::getName(n);
 		} else {
-			return 0xff;
+			return qs;
 		}
 	} else {
-		return -1;
+		return "";
 	}
 }
 
@@ -567,8 +565,7 @@ int TagLibFile::getGenreNumV2()
 QString TagLibFile::getGenreV2()
 {
 	if (m_tagV2) {
-		TagLib::String str = m_tagV2->genre();
-		return str.isNull() ? QString("") : TStringToQString(str);
+		return getGenreString(m_tagV2->genre());
 	} else {
 		return QString::null;
 	}
@@ -639,8 +636,12 @@ void TagLibFile::setTitleV1(const QString& str)
 		TagLib::String tstr = str.isEmpty() ?
 			TagLib::String::null : QStringToTString(str);
 		if (!(tstr == m_tagV1->title())) {
-			m_tagV1->setTitle(tstr);
-			changedV1 = true;
+			QString s = checkTruncation(str, StandardTags::TF_Title);
+			if (!s.isNull())
+				m_tagV1->setTitle(QStringToTString(s));
+			else
+				m_tagV1->setTitle(tstr);
+			markTag1Changed();
 		}
 	}
 }
@@ -656,8 +657,12 @@ void TagLibFile::setArtistV1(const QString& str)
 		TagLib::String tstr = str.isEmpty() ?
 			TagLib::String::null : QStringToTString(str);
 		if (!(tstr == m_tagV1->artist())) {
-			m_tagV1->setArtist(tstr);
-			changedV1 = true;
+			QString s = checkTruncation(str, StandardTags::TF_Artist);
+			if (!s.isNull())
+				m_tagV1->setArtist(QStringToTString(s));
+			else
+				m_tagV1->setArtist(tstr);
+			markTag1Changed();
 		}
 	}
 }
@@ -673,8 +678,12 @@ void TagLibFile::setAlbumV1(const QString& str)
 		TagLib::String tstr = str.isEmpty() ?
 			TagLib::String::null : QStringToTString(str);
 		if (!(tstr == m_tagV1->album())) {
-			m_tagV1->setAlbum(tstr);
-			changedV1 = true;
+			QString s = checkTruncation(str, StandardTags::TF_Album);
+			if (!s.isNull())
+				m_tagV1->setAlbum(QStringToTString(s));
+			else
+				m_tagV1->setAlbum(tstr);
+			markTag1Changed();
 		}
 	}
 }
@@ -690,8 +699,12 @@ void TagLibFile::setCommentV1(const QString& str)
 		TagLib::String tstr = str.isEmpty() ?
 			TagLib::String::null : QStringToTString(str);
 		if (!(tstr == m_tagV1->comment())) {
-			m_tagV1->setComment(tstr);
-			changedV1 = true;
+			QString s = checkTruncation(str, StandardTags::TF_Comment, 28);
+			if (!s.isNull())
+				m_tagV1->setComment(QStringToTString(s));
+			else
+				m_tagV1->setComment(tstr);
+			markTag1Changed();
 		}
 	}
 }
@@ -706,7 +719,7 @@ void TagLibFile::setYearV1(int num)
 	if (makeTagV1Settable() && num >= 0) {
 		if (num != static_cast<int>(m_tagV1->year())) {
 			m_tagV1->setYear(num);
-			changedV1 = true;
+			markTag1Changed();
 		}
 	}
 }
@@ -720,27 +733,33 @@ void TagLibFile::setTrackNumV1(int num)
 {
 	if (makeTagV1Settable() && num >= 0) {
 		if (num != static_cast<int>(m_tagV1->track())) {
-			m_tagV1->setTrack(num);
-			changedV1 = true;
+			int n = checkTruncation(num, StandardTags::TF_Track);
+			if (n != -1)
+				m_tagV1->setTrack(n);
+			else
+				m_tagV1->setTrack(num);
+			markTag1Changed();
 		}
 	}
 }
 
 /**
- * Set ID3v1 genre.
+ * Set ID3v1 genre as text.
  *
- * @param num number to set, 0xff to remove field.
+ * @param str string to set, "" to remove field, QString::null to ignore.
  */
-void TagLibFile::setGenreNumV1(int num)
+void TagLibFile::setGenreV1(const QString& str)
 {
-	if (makeTagV1Settable() && num >= 0) {
-		const char* str = Genres::getName(num);
-		TagLib::String tstr = str && *str ?
-			TagLib::String(str) : TagLib::String::null;
+	if (makeTagV1Settable() && !str.isNull()) {
+		TagLib::String tstr = str.isEmpty() ?
+			TagLib::String::null : QStringToTString(str);
 		if (!(tstr == m_tagV1->genre())) {
 			m_tagV1->setGenre(tstr);
-			changedV1 = true;
+			markTag1Changed();
 		}
+		// if the string cannot be converted to a number, set the truncation flag
+		checkTruncation(!str.isEmpty() && Genres::getNumber(str) == 0xff ? 1 : 0,
+										StandardTags::TF_Genre, 0);
 	}
 }
 
@@ -749,7 +768,7 @@ void TagLibFile::setGenreNumV1(int num)
  *
  * @param tag     tag
  * @param qstr    text as QString
- * @param tst     text as TagLib::String
+ * @param tstr    text as TagLib::String
  * @param frameId ID3v2 frame ID
  *
  * @return true if an ID3v2 Unicode field was written.
@@ -814,7 +833,7 @@ void TagLibFile::setTitleV2(const QString& str)
 			if (!setId3v2Unicode(m_tagV2, str, tstr, "TIT2")) {
 				m_tagV2->setTitle(tstr);
 			}
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
@@ -833,7 +852,7 @@ void TagLibFile::setArtistV2(const QString& str)
 			if (!setId3v2Unicode(m_tagV2, str, tstr, "TPE1")) {
 			}
 			m_tagV2->setArtist(tstr);
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
@@ -852,7 +871,7 @@ void TagLibFile::setAlbumV2(const QString& str)
 			if (!setId3v2Unicode(m_tagV2, str, tstr, "TALB")) {
 			}
 			m_tagV2->setAlbum(tstr);
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
@@ -871,7 +890,7 @@ void TagLibFile::setCommentV2(const QString& str)
 			if (!setId3v2Unicode(m_tagV2, str, tstr, "COMM")) {
 			}
 			m_tagV2->setComment(tstr);
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
@@ -886,7 +905,7 @@ void TagLibFile::setYearV2(int num)
 	if (makeTagV2Settable() && num >= 0) {
 		if (num != static_cast<int>(m_tagV2->year())) {
 			m_tagV2->setYear(num);
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
@@ -927,25 +946,7 @@ void TagLibFile::setTrackNumV2(int num)
 			} else {
 				m_tagV2->setTrack(num);
 			}
-			changedV2 = true;
-		}
-	}
-}
-
-/**
- * Set ID3v2 genre.
- *
- * @param num number to set, 0xff to remove field.
- */
-void TagLibFile::setGenreNumV2(int num)
-{
-	if (makeTagV2Settable() && num >= 0) {
-		const char* str = Genres::getName(num);
-		TagLib::String tstr = str && *str ?
-			TagLib::String(str) : TagLib::String::null;
-		if (!(tstr == m_tagV2->genre())) {
-			m_tagV2->setGenre(tstr);
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
@@ -962,7 +963,7 @@ void TagLibFile::setGenreV2(const QString& str)
 			TagLib::String::null : QStringToTString(str);
 		if (!(tstr == m_tagV2->genre())) {
 			m_tagV2->setGenre(tstr);
-			changedV2 = true;
+			markTag2Changed();
 		}
 	}
 }
