@@ -164,10 +164,6 @@ class TagLibFieldControl : public FieldControl {
 public:
 	/**
 	 * Constructor.
-	 *
-	 * @param fl  frame list
-	 * @param id  ID of field
-	 * @param fld ID3 field
 	 */
 	TagLibFieldControl() {}
 
@@ -475,7 +471,8 @@ class TagLibBinFieldControl : public TagLibFieldControl {
  public:
 	/**
 	 * Constructor.
-	 * @param label label
+	 * @param label      label
+	 * @param viewButton true to display a View button
 	 */
 	explicit TagLibBinFieldControl(const QString& label, bool viewButton = false) :
 	m_label(label), m_viewButton(viewButton) {}
@@ -719,11 +716,11 @@ public:
 										 Q3PtrList<FieldControl> &ctls);
 
 protected:
-	QVBoxLayout* m_vlayout;
-	QHBoxLayout* m_hlayout;
-	QSpacerItem* m_hspacer;
-	QPushButton* m_okButton;
-	QPushButton* m_cancelButton;
+	QVBoxLayout* m_vlayout;      /**< vertical layout */
+	QHBoxLayout* m_hlayout;      /**< horizontal layout */
+	QSpacerItem* m_hspacer;      /**< horizontal spacer */
+	QPushButton* m_okButton;     /**< OK button */
+	QPushButton* m_cancelButton; /**< Cancel button */
 };
 
 /**
@@ -734,7 +731,7 @@ protected:
  * @param ctls    list with controls to edit fields
  */
 TagLibEditFrameDialog::TagLibEditFrameDialog(
-	QWidget* parent, const QString &caption, Q3PtrList<FieldControl> &ctls) :
+	QWidget* parent, const QString& caption, Q3PtrList<FieldControl>& ctls) :
 	QDialog(parent, "edit_frame", true)
 {
 	setCaption(caption);
@@ -909,20 +906,22 @@ QString TagLibFrameList::getId3v2FrameDescription(
  */
 void TagLibFrameList::readTags()
 {
-	listbox->clear();
+	s_listbox->clear();
 	if (m_tag) {
 		TagLib::ID3v2::Tag* id3v2Tag;
 		TagLib::Ogg::XiphComment* oggTag;
 		TagLib::APE::Tag* apeTag;
 		if ((id3v2Tag = dynamic_cast<TagLib::ID3v2::Tag*>(m_tag)) != 0) {
 			const TagLib::ID3v2::FrameList& frameList = id3v2Tag->frameList();
+			int i = 0;
 			for (TagLib::ID3v2::FrameList::ConstIterator it = frameList.begin();
 					 it != frameList.end();
 					 ++it) {
-				listbox->insertItem(getId3v2FrameDescription((*it)->frameID()));
+				new FrameListItem(s_listbox, getId3v2FrameDescription((*it)->frameID()), i++);
 			}
 		} else if ((oggTag = dynamic_cast<TagLib::Ogg::XiphComment*>(m_tag)) != 0) {
 			const TagLib::Ogg::FieldListMap& fieldListMap = oggTag->fieldListMap();
+			int i = 0;
 			for (TagLib::Ogg::FieldListMap::ConstIterator it = fieldListMap.begin();
 					 it != fieldListMap.end();
 					 ++it) {
@@ -931,17 +930,19 @@ void TagLibFrameList::readTags()
 				for (TagLib::StringList::ConstIterator slit = stringList.begin();
 						 slit != stringList.end();
 						 ++slit) {
-					listbox->insertItem(id);
+					new FrameListItem(s_listbox, id, i++);
 				}
 			}
 		} else if ((apeTag = dynamic_cast<TagLib::APE::Tag*>(m_tag)) != 0) {
 			const TagLib::APE::ItemListMap& itemListMap = apeTag->itemListMap();
+			int i = 0;
 			for (TagLib::APE::ItemListMap::ConstIterator it = itemListMap.begin();
 					 it != itemListMap.end();
 					 ++it) {
-				listbox->insertItem(TStringToQString((*it).first));
+				new FrameListItem(s_listbox, TStringToQString((*it).first), i++);
 			}
 		}
+		s_listbox->sort();
 	}
 }
 
@@ -1096,12 +1097,11 @@ static const char* encodingStrLst[] = {
 	I18N_NOOP("UTF16"),
 	I18N_NOOP("UTF16BE"),
 	I18N_NOOP("UTF8"),
-	I18N_NOOP("UTF16LE"),
 	0
 };
 
 /**
- * Edit a text identificatin frame.
+ * Edit a text identification frame.
  *
  * @param tFrame text identification frame
  * @param id     frame ID
@@ -1830,15 +1830,16 @@ TagLib::ID3v2::Frame* TagLibFrameList::editId3v2Frame(
 bool TagLibFrameList::editFrame()
 {
 	bool edited = false;
-	int selectedIndex = listbox->currentItem();
-	if (selectedIndex != -1 && m_tag) {
+	int selectedIndex = s_listbox->currentItem();
+	int selectedId = getSelectedId();
+	if (selectedId != -1 && m_tag) {
 		TagLib::ID3v2::Tag* id3v2Tag;
 		TagLib::Ogg::XiphComment* oggTag;
 		TagLib::APE::Tag* apeTag;
 		if ((id3v2Tag = dynamic_cast<TagLib::ID3v2::Tag*>(m_tag)) != 0) {
 			const TagLib::ID3v2::FrameList& frameList = id3v2Tag->frameList();
-			if (selectedIndex < static_cast<int>(frameList.size())) {
-				TagLib::ID3v2::Frame* oldFrame = frameList[selectedIndex];
+			if (selectedId < static_cast<int>(frameList.size())) {
+				TagLib::ID3v2::Frame* oldFrame = frameList[selectedId];
 				TagLib::ID3v2::Frame* newFrame;
 				if ((newFrame = editId3v2Frame(oldFrame)) != 0) {
 					id3v2Tag->removeFrame(oldFrame);
@@ -1848,7 +1849,7 @@ bool TagLibFrameList::editFrame()
 			}
 		} else if ((oggTag = dynamic_cast<TagLib::Ogg::XiphComment*>(m_tag)) != 0) {
 			TagLib::String key, value;
-			if (getXiphCommentField(*oggTag, selectedIndex, key, value)) {
+			if (getXiphCommentField(*oggTag, selectedId, key, value)) {
 				TagLib::String oldValue = value;
 				if (editKeyValueField(key, value)) {
 					if (!(value == oldValue)) {
@@ -1868,7 +1869,7 @@ bool TagLibFrameList::editFrame()
 		} else if ((apeTag = dynamic_cast<TagLib::APE::Tag*>(m_tag)) != 0) {
 			TagLib::String key;
 			TagLib::APE::Item item;
-			if (getApeItem(*apeTag, selectedIndex, key, item)) {
+			if (getApeItem(*apeTag, selectedId, key, item)) {
 				TagLib::StringList values = item.toStringList();
 				TagLib::String value = values.size() > 0 ? values.front() : "";
 				TagLib::String oldValue = value;
@@ -1885,14 +1886,15 @@ bool TagLibFrameList::editFrame()
 		readTags(); // refresh listbox
 		// select the next item (or the last if it was the last)
 		if (selectedIndex >= 0) {
-			const int lastIndex = listbox->count() - 1;
+			const int lastIndex = s_listbox->count() - 1;
 			if (lastIndex >= 0) {
-				listbox->setSelected(
+				s_listbox->setSelected(
 					selectedIndex <= lastIndex ? selectedIndex : lastIndex, true);
+				s_listbox->ensureCurrentVisible();
 			}
 		}
 		if (m_file) {
-			m_file->changedV2 = true;
+			m_file->markTag2Changed();
 		}
 	}
 	return edited;
@@ -1906,20 +1908,21 @@ bool TagLibFrameList::editFrame()
 bool TagLibFrameList::deleteFrame()
 {
 	bool deleted = false;
-	int selectedIndex = listbox->currentItem();
-	if (selectedIndex != -1 && m_tag) {
+	int selectedIndex = s_listbox->currentItem();
+	int selectedId = getSelectedId();
+	if (selectedId != -1 && m_tag) {
 		TagLib::ID3v2::Tag* id3v2Tag;
 		TagLib::Ogg::XiphComment* oggTag;
 		TagLib::APE::Tag* apeTag;
 		if ((id3v2Tag = dynamic_cast<TagLib::ID3v2::Tag*>(m_tag)) != 0) {
 			const TagLib::ID3v2::FrameList& frameList = id3v2Tag->frameList();
-			if (selectedIndex < static_cast<int>(frameList.size())) {
-				id3v2Tag->removeFrame(frameList[selectedIndex]);
+			if (selectedId < static_cast<int>(frameList.size())) {
+				id3v2Tag->removeFrame(frameList[selectedId]);
 				deleted = true;
 			}
 		} else if ((oggTag = dynamic_cast<TagLib::Ogg::XiphComment*>(m_tag)) != 0) {
 			TagLib::String key, value;
-			if (getXiphCommentField(*oggTag, selectedIndex, key, value)) {
+			if (getXiphCommentField(*oggTag, selectedId, key, value)) {
 #ifdef TAGLIB_XIPHCOMMENT_REMOVEFIELD_CRASHES
 				oggTag->removeField(key);
 #else
@@ -1933,7 +1936,7 @@ bool TagLibFrameList::deleteFrame()
 		} else if ((apeTag = dynamic_cast<TagLib::APE::Tag*>(m_tag)) != 0) {
 			TagLib::String key;
 			TagLib::APE::Item item;
-			if (getApeItem(*apeTag, selectedIndex, key, item)) {
+			if (getApeItem(*apeTag, selectedId, key, item)) {
 				apeTag->removeItem(key);
 				deleted = true;
 			}
@@ -1942,14 +1945,15 @@ bool TagLibFrameList::deleteFrame()
 			readTags(); // refresh listbox
 			// select the next item (or the last if it was the last)
 			if (selectedIndex >= 0) {
-				const int lastIndex = listbox->count() - 1;
+				const int lastIndex = s_listbox->count() - 1;
 				if (lastIndex >= 0) {
-					listbox->setSelected(
+					s_listbox->setSelected(
 						selectedIndex <= lastIndex ? selectedIndex : lastIndex, true);
+					s_listbox->ensureCurrentVisible();
 				}
 			}
 			if (m_file) {
-				m_file->changedV2 = true;
+				m_file->markTag2Changed();
 			}
 			return true;
 		}
@@ -2048,11 +2052,10 @@ bool TagLibFrameList::addFrame(int frameId, bool edit)
 				if (newFrame) {
 					id3v2Tag->addFrame(newFrame);
 					added = true;
+					int frameIndex = id3v2Tag->frameList().size() - 1;
 					readTags(); // refresh listbox
-					const int lastIndex = listbox->count() - 1;
-					if (lastIndex >= 0) {
-						listbox->setSelected(lastIndex, true);
-					}
+					setSelectedId(frameIndex);
+					s_listbox->ensureCurrentVisible();
 				}
 			}
 		} else if ((oggTag = dynamic_cast<TagLib::Ogg::XiphComment*>(m_tag)) != 0) {
@@ -2065,9 +2068,10 @@ bool TagLibFrameList::addFrame(int frameId, bool edit)
 				oggTag->addField(key, value);
 				added = true;
 				readTags(); // refresh listbox
-				Q3ListBoxItem* lbi = listbox->findItem(m_selectedName);
+				Q3ListBoxItem* lbi = s_listbox->findItem(m_selectedName);
 				if (lbi) {
-					listbox->setSelected(lbi, true);
+					s_listbox->setSelected(lbi, true);
+					s_listbox->ensureCurrentVisible();
 				}
 			}
 		} else if ((apeTag = dynamic_cast<TagLib::APE::Tag*>(m_tag)) != 0) {
@@ -2080,15 +2084,16 @@ bool TagLibFrameList::addFrame(int frameId, bool edit)
 				apeTag->addValue(key, value, true);
 				added = true;
 				readTags(); // refresh listbox
-				Q3ListBoxItem* lbi = listbox->findItem(m_selectedName);
+				Q3ListBoxItem* lbi = s_listbox->findItem(m_selectedName);
 				if (lbi) {
-					listbox->setSelected(lbi, true);
+					s_listbox->setSelected(lbi, true);
+					s_listbox->ensureCurrentVisible();
 				}
 			}
 		}
 		if (added) {
 			if (m_file) {
-				m_file->changedV2 = true;
+				m_file->markTag2Changed();
 			}
 		}
 	}
@@ -2186,7 +2191,12 @@ int TagLibFrameList::selectFrameId()
 			bool ok = false;
 			QString res = QInputDialog::getItem(
 				i18n("Add Frame"),
-				i18n("Select the frame ID"), lst, 0, true, &ok);
+				i18n("Select the frame ID")
+#if QT_VERSION >= 0x040000
+				// the dialog is too small in Qt4
+				+ "                                     "
+#endif
+				, lst, 0, true, &ok);
 			if (ok) {
 				m_selectedName = res;
 				return 0; // just used by addFrame()
@@ -2204,20 +2214,20 @@ int TagLibFrameList::selectFrameId()
 bool TagLibFrameList::copyFrame()
 {
 	bool copied = false;
-	int selectedIndex = listbox->currentItem();
-	if (selectedIndex != -1 && m_tag) {
+	int selectedId = getSelectedId();
+	if (selectedId != -1 && m_tag) {
 		TagLib::ID3v2::Tag* id3v2Tag;
 		TagLib::Ogg::XiphComment* oggTag;
 		TagLib::APE::Tag* apeTag;
 		if ((id3v2Tag = dynamic_cast<TagLib::ID3v2::Tag*>(m_tag)) != 0) {
 			const TagLib::ID3v2::FrameList& frameList = id3v2Tag->frameList();
-			if (selectedIndex < static_cast<int>(frameList.size())) {
-				m_copyData = frameList[selectedIndex]->render();
+			if (selectedId < static_cast<int>(frameList.size())) {
+				m_copyData = frameList[selectedId]->render();
 				copied = true;
 			}
 		} else if ((oggTag = dynamic_cast<TagLib::Ogg::XiphComment*>(m_tag)) != 0) {
 			TagLib::String key, value;
-			if (getXiphCommentField(*oggTag, selectedIndex, key, value)) {
+			if (getXiphCommentField(*oggTag, selectedId, key, value)) {
 				m_copyKey = key;
 				m_copyValue = value;
 				copied = true;
@@ -2225,7 +2235,7 @@ bool TagLibFrameList::copyFrame()
 		} else if ((apeTag = dynamic_cast<TagLib::APE::Tag*>(m_tag)) != 0) {
 			TagLib::String key;
 			TagLib::APE::Item item;
-			if (getApeItem(*apeTag, selectedIndex, key, item)) {
+			if (getApeItem(*apeTag, selectedId, key, item)) {
 				m_copyKey = key;
 				TagLib::StringList values = item.toStringList();
 				m_copyValue = values.size() > 0 ? values.front() : "";
@@ -2271,7 +2281,7 @@ bool TagLibFrameList::pasteFrame()
 		}
 	}
 	if (pasted && m_file) {
-		m_file->changedV2 = true;
+		m_file->markTag2Changed();
 	}
 	return pasted;
 }
